@@ -5,17 +5,16 @@ from uuid import UUID
 
 import affine
 import attr
-from eodatasets3 import utils
-from eodatasets3.properties import StacPropertyView, EoFields
 from ruamel.yaml.comments import CommentedMap
 from shapely.geometry.base import BaseGeometry
 
+from eodatasets3 import utils
+from eodatasets3.properties import StacPropertyView, EoFields
 
 # TODO: these need discussion.
 DEA_URI_PREFIX = "https://collections.dea.ga.gov.au"
 ODC_DATASET_SCHEMA_URL = "https://schemas.opendatacube.org/dataset"
 
-
 # Either a local filesystem path or a string URI.
 # (the URI can use any scheme supported by rasterio, such as tar:// or https:// or ...)
 Location = Union[Path, str]
@@ -373,6 +372,80 @@ class ComplicatedNamingConventions:
             )
 
 
+class ComplicatedNamingConventionsDerivatives(ComplicatedNamingConventions):
+    """
+    This class is inherited from ComplicatedNamingConventions
+    and overrides few attributes specific to C3 data processing for data other than ARD.
+    """
+
+    @classmethod
+    def for_c3_derivatives(cls, dataset: EoFields, uri=DEA_URI_PREFIX):
+        """
+        The required fields for the c3 data processing are controlled here.
+        """
+        return cls(
+            dataset=dataset,
+            base_product_uri=uri,
+            required_fields=(
+                "eo:platform",
+                "odc:dataset_version",
+                "odc:collection_number",
+                "odc:processing_datetime",
+                "odc:producer",
+                "odc:product_family",
+                "odc:region_code",
+                "dea:dataset_maturity",
+            ),
+        )
+
+    @property
+    def _org_collection_number(self) -> Optional[int]:
+        # Deliberately fail if collection_number is not defined in the config yaml
+        return int(self.dataset.collection_number)
+
+    def _product_group(self, subname=None) -> str:
+        # Computues product group, e.g "ga_ls_wo_3"
+        # Deliberately fail if any of these attributes not found.
+        parts = [
+            self.producer_abbreviated,
+            self.platform_abbreviated,
+            self.dataset.product_family,
+        ]
+        return "_".join(parts)
+
+    def destination_folder(self, base: Path):
+        self._check_enough_properties_to_name()
+        parts = [self.product_name, self.dataset.dataset_version.replace(".", "-")]
+        parts.extend(utils.subfolderise(self.dataset.region_code))
+        parts.extend(f"{self.dataset.datetime:%Y/%m/%d}".split("/"))
+        return base.joinpath(*parts)
+
+    def _dataset_label(self, sub_name: str = None):
+        """
+        Responsible for producing the string of product name, regioncode, datetime and maturity
+        ex: 'ga_ls_wo_3_090081_1998-07-30_interim'
+
+        Redundant parameter sub_name is required, since the parent class and other invocations wants it so.
+        """
+        parts = [
+            self.product_name,
+            self._displayable_region_code,
+            f"{self.dataset.datetime:%Y-%m-%d}",
+            self.dataset.maturity,
+        ]
+        return "_".join(parts)
+
+    @property
+    def platform_abbreviated(self) -> Optional[str]:
+        # For now from Alchemist the platform is always landsat for C3 processing
+        if "landsat" not in self.dataset.platform:
+            raise NotImplementedError(
+                f"Only Landsat platforms currently implemented for dea_c3 naming schemes "
+                f"(got {self.dataset.platform!r})"
+            )
+        return "ls"
+
+
 @attr.s(auto_attribs=True, slots=True)
 class DatasetDoc(EoFields):
     id: UUID = None
